import { useState, useEffect, lazy, Suspense } from "react";
import { Tag, Shield, Eye, Menu, X, ChevronDown } from "lucide-react";
import { Link } from "wouter";

// Import components normally to ensure proper loading
import { OrderFormModal } from "@/components/order-form-modal";
import { FAQAccordion } from "@/components/faq-accordion"; 
import { StickyCTA } from "@/components/sticky-cta";

export default function Home() {
  const [isOrderModalOpen, setIsOrderModalOpen] = useState(false);
  const [isMobileMenuOpen, setIsMobileMenuOpen] = useState(false);

  const scrollToSection = (sectionId: string) => {
    const element = document.getElementById(sectionId);
    if (element) {
      element.scrollIntoView({ behavior: 'smooth' });
    }
    setIsMobileMenuOpen(false);
  };

  return (
    <div className="min-h-screen">
      {/* Header */}
      <header className="bg-white shadow-sm sticky top-0 z-50">
        <div className="max-w-6xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="flex justify-between items-center h-16">
            {/* Logo */}
            <div className="flex items-center">
              <img 
                src="/sheet-sherlock-logo.webp" 
                alt="Sheet Sherlock - Smart Linen Identification" 
                className="h-8 w-auto object-contain sm:h-10 md:h-12"
                loading="eager"
                decoding="async"
                width="200"
                height="50"
              />
            </div>

            {/* Desktop Navigation */}
            <nav className="hidden md:flex space-x-8">
              <button 
                onClick={() => scrollToSection('benefits')}
                className="text-gray-600 hover:text-[#49c3c3] transition-colors duration-300 font-medium"
              >
                Benefits
              </button>
              <button 
                onClick={() => scrollToSection('how-it-works')}
                className="text-gray-600 hover:text-[#49c3c3] transition-colors duration-300 font-medium"
              >
                How It Works
              </button>
              <button 
                onClick={() => scrollToSection('faq')}
                className="text-gray-600 hover:text-[#49c3c3] transition-colors duration-300 font-medium"
              >
                FAQ
              </button>
            </nav>

            {/* Mobile Menu Button */}
            <button 
              onClick={() => setIsMobileMenuOpen(!isMobileMenuOpen)}
              className="md:hidden p-2 text-gray-600 hover:text-[#49c3c3]"
            >
              {isMobileMenuOpen ? <X size={24} /> : <Menu size={24} />}
            </button>
          </div>

          {/* Mobile Menu */}
          {isMobileMenuOpen && (
            <div className="md:hidden border-t border-gray-200 py-4">
              <div className="flex flex-col space-y-4">
                <button 
                  onClick={() => scrollToSection('benefits')}
                  className="text-gray-600 hover:text-[#49c3c3] transition-colors duration-300 font-medium text-left"
                >
                  Benefits
                </button>
                <button 
                  onClick={() => scrollToSection('how-it-works')}
                  className="text-gray-600 hover:text-[#49c3c3] transition-colors duration-300 font-medium text-left"
                >
                  How It Works
                </button>
                <button 
                  onClick={() => scrollToSection('faq')}
                  className="text-gray-600 hover:text-[#49c3c3] transition-colors duration-300 font-medium text-left"
                >
                  FAQ
                </button>
              </div>
            </div>
          )}
        </div>
      </header>

      {/* Hero Section */}
      <section className="gradient-banner text-white py-12 sm:py-16 lg:py-20">
        <div className="max-w-6xl mx-auto px-4 sm:px-6 lg:px-8 text-center">
          <div className="animate-fade-in">
            <p className="text-base sm:text-lg font-medium mb-2 opacity-90">Built by a host. Trusted by pros.</p>
            <h1 className="text-3xl sm:text-4xl md:text-5xl lg:text-6xl font-poppins font-bold mb-4 sm:mb-6 leading-tight">
              Your Linen, Under Control.<br />
              <span className="text-2xl sm:text-3xl md:text-4xl lg:text-5xl">Every Unit. Every Turnover.<br />Even When You're Off-Site</span>
            </h1>
            <p className="text-base sm:text-lg md:text-xl leading-relaxed max-w-4xl mx-auto mb-6 sm:mb-8 opacity-95">
              If you manage multiple short-term rentals, you know the frustration of missing sheets, wrong sizes on beds, and wasted time showing staff. Sheet Sherlock solves it fast. Our iron-on ID tags and mobile app let you track every sheet by size, set, and unit at a glance. No more guesswork. Just smoother operations, faster turnovers, and 5-star stays.
            </p>
            <button 
              onClick={() => {
                console.log('Hero CTA clicked');
                setIsOrderModalOpen(true);
              }}
              className="bg-white text-[#ff4fa1] px-6 py-3 sm:px-8 sm:py-4 rounded-lg font-semibold text-base sm:text-lg shadow-lg hover:shadow-xl transform hover:scale-105 transition-all duration-300"
            >
              Get Sheet Sherlock
            </button>
          </div>
        </div>
      </section>

      {/* Benefits Section */}
      <section id="benefits" className="py-12 sm:py-16 px-4 sm:px-6 lg:px-8 bg-gray-50">
        <div className="max-w-6xl mx-auto">
          <div className="text-center mb-8 sm:mb-12">
            <h2 className="text-2xl sm:text-3xl md:text-4xl font-poppins font-bold text-[#49c3c3] mb-4">Why Sheet Sherlock Works</h2>
            <p className="text-base sm:text-lg text-gray-600 max-w-2xl mx-auto">Transform your linen management with our proven system</p>
          </div>
          <div className="grid gap-6 sm:gap-8 md:grid-cols-3">
            {/* Benefit 1 */}
            <div className="gradient-card rounded-xl p-4 sm:p-6 shadow-lg hover:shadow-xl transform hover:-translate-y-1 transition-all duration-300 animate-slide-up">
              <div className="w-10 h-10 sm:w-12 sm:h-12 bg-[#49c3c3] rounded-lg flex items-center justify-center mb-4">
                <Tag className="text-white" size={20} />
              </div>
              <h3 className="text-lg sm:text-xl font-poppins font-semibold text-[#49c3c3] mb-3">Tag every sheet with unit, size, and purchase details</h3>
              <p className="text-sm sm:text-base text-gray-700 leading-relaxed">Know exactly what goes where — no more guessing, unfolding, or digging through closets.</p>
            </div>

            {/* Benefit 2 */}
            <div className="gradient-card rounded-xl p-4 sm:p-6 shadow-lg hover:shadow-xl transform hover:-translate-y-1 transition-all duration-300 animate-slide-up" style={{animationDelay: '0.1s'}}>
              <div className="w-10 h-10 sm:w-12 sm:h-12 bg-[#ff4fa1] rounded-lg flex items-center justify-center mb-4">
                <Shield className="text-white" size={20} />
              </div>
              <h3 className="text-lg sm:text-xl font-poppins font-semibold text-[#49c3c3] mb-3">Eliminate mix-ups and staff errors — even with rotating teams</h3>
              <p className="text-sm sm:text-base text-gray-700 leading-relaxed">Your cleaners get it right the first time, every time. No extra training, no follow-ups, no frustrated guests.</p>
            </div>

            {/* Benefit 3 */}
            <div className="gradient-card rounded-xl p-4 sm:p-6 shadow-lg hover:shadow-xl transform hover:-translate-y-1 transition-all duration-300 animate-slide-up" style={{animationDelay: '0.2s'}}>
              <div className="w-10 h-10 sm:w-12 sm:h-12 bg-[#8b5cf6] rounded-lg flex items-center justify-center mb-4">
                <Eye className="text-white" size={20} />
              </div>
              <h3 className="text-lg sm:text-xl font-poppins font-semibold text-[#49c3c3] mb-3">Hands-off linen tracking that saves you money</h3>
              <p className="text-sm sm:text-base text-gray-700 leading-relaxed">See at a glance what you own, when it was bought, and when it's time to replace — no spreadsheets, no micromanaging.</p>
            </div>
          </div>
        </div>
      </section>

      {/* Testimonials Section */}
      <section className="py-12 sm:py-16 px-4 sm:px-6 lg:px-8 bg-white">
        <div className="max-w-4xl mx-auto text-center">
          <h2 className="text-2xl sm:text-3xl font-poppins font-bold text-[#49c3c3] mb-8 sm:mb-12">What Hosts Are Saying</h2>
          <div className="grid gap-6 sm:gap-8 md:grid-cols-2">
            <div className="bg-[#e0f7fa] rounded-xl p-4 sm:p-6 shadow-lg">
              <div className="text-[#49c3c3] text-3xl sm:text-4xl mb-4">
                <span>"</span>
              </div>
              <p className="text-base sm:text-lg text-gray-700 mb-4 leading-relaxed">Thank you so much !!! It is a real game changer to use your tags! I've started to use it in my Airbnb and I am hugely impressed!</p>
              <div className="font-semibold text-[#49c3c3]">— Katryn, AirBNB Host</div>
            </div>
            <div className="bg-[#fce7f3] rounded-xl p-4 sm:p-6 shadow-lg">
              <div className="text-[#ff4fa1] text-3xl sm:text-4xl mb-4">
                <span>"</span>
              </div>
              <p className="text-base sm:text-lg text-gray-700 mb-4 leading-relaxed">It's like a little fairy in your linen cupboard!</p>
              <div className="font-semibold text-[#ff4fa1]">— Catherine, Property Manager</div>
            </div>
          </div>
        </div>
      </section>

      {/* Product Offer Section */}
      <section className="py-12 sm:py-16 px-4 sm:px-6 lg:px-8 bg-gradient-to-br from-[#e0f7fa] to-[#fce7f3]">
        <div className="max-w-4xl mx-auto text-center">
          <div className="bg-white rounded-2xl shadow-2xl p-6 sm:p-8 md:p-12">
            <h2 className="text-2xl sm:text-3xl md:text-4xl font-poppins font-bold text-[#49c3c3] mb-4 sm:mb-6">Try the Sheet Sherlock Starter Pack</h2>
            
            <div className="grid gap-6 sm:gap-8 md:grid-cols-2 items-center mb-6 sm:mb-8">
              <div className="text-left">
                <ul className="space-y-2 sm:space-y-3 text-base sm:text-lg">
                  <li className="flex items-center">
                    <span className="text-green-500 mr-3 text-lg">✓</span>
                    <span>100 durable iron-on LinTags</span>
                  </li>
                  <li className="flex items-center">
                    <span className="text-green-500 mr-3 text-lg">✓</span>
                    <span>Full mobile app access</span>
                  </li>
                  <li className="flex items-center">
                    <span className="text-green-500 mr-3 text-lg">✓</span>
                    <span>Free delivery</span>
                  </li>
                  <li className="flex items-center">
                    <span className="text-green-500 mr-3 text-lg">✓</span>
                    <span>Coming soon: Linen stock dashboard</span>
                  </li>
                </ul>
              </div>
              <div className="text-center">
                <div className="text-3xl sm:text-4xl lg:text-5xl font-bold text-[#ff4fa1] mb-2">💸 $137</div>
                <button 
                  onClick={() => setIsOrderModalOpen(true)}
                  className="bg-[#ff4fa1] text-white px-6 py-3 sm:px-8 sm:py-4 rounded-lg font-semibold text-base sm:text-lg shadow-lg hover:shadow-xl transform hover:scale-105 transition-all duration-300 w-full md:w-auto"
                >
                  Get Sheet Sherlock
                </button>
              </div>
            </div>
            
            <div className="bg-gray-50 rounded-lg p-3 sm:p-4 text-xs sm:text-sm text-gray-600">
              <p className="mb-2"><strong>No credit card details required</strong></p>
              <p>The first 50 customers will be exclusively invited to help shape our upcoming linen stock dashboard — built around your real operational needs.</p>
            </div>
          </div>
        </div>
      </section>

      {/* How It Works Section */}
      <section id="how-it-works" className="py-12 sm:py-16 px-4 sm:px-6 lg:px-8 bg-white">
        <div className="max-w-6xl mx-auto">
          <div className="text-center mb-8 sm:mb-12">
            <h2 className="text-2xl sm:text-3xl md:text-4xl font-poppins font-bold text-[#49c3c3] mb-4">How It Works</h2>
            <p className="text-base sm:text-lg text-gray-600">Three simple steps to linen control</p>
          </div>
          <div className="grid gap-6 sm:gap-8 md:grid-cols-3">
            {/* Step 1 */}
            <div className="text-center">
              <div className="w-12 h-12 sm:w-16 sm:h-16 bg-[#49c3c3] rounded-full flex items-center justify-center text-xl sm:text-2xl font-bold text-white mx-auto mb-4">1</div>
              <h3 className="text-lg sm:text-xl font-poppins font-semibold text-[#49c3c3] mb-3">Iron LinTags onto your linen</h3>
              <p className="text-sm sm:text-base text-gray-600">Apply our durable iron-on tags to each sheet with unit and size information</p>
            </div>
            {/* Step 2 */}
            <div className="text-center">
              <div className="w-12 h-12 sm:w-16 sm:h-16 bg-[#ff4fa1] rounded-full flex items-center justify-center text-xl sm:text-2xl font-bold text-white mx-auto mb-4">2</div>
              <h3 className="text-lg sm:text-xl font-poppins font-semibold text-[#49c3c3] mb-3">Scan to embed details with the app with 1 tap</h3>
              <p className="text-sm sm:text-base text-gray-600">Use your smartphone to quickly scan and record linen details</p>
            </div>
            {/* Step 3 */}
            <div className="text-center">
              <div className="w-12 h-12 sm:w-16 sm:h-16 bg-[#8b5cf6] rounded-full flex items-center justify-center text-xl sm:text-2xl font-bold text-white mx-auto mb-4">3</div>
              <h3 className="text-lg sm:text-xl font-poppins font-semibold text-[#49c3c3] mb-3">Sort, track, and manage effortlessly</h3>
              <p className="text-gray-600">Keep everything organized with instant visibility into your linen inventory</p>
            </div>
          </div>
        </div>
      </section>

      {/* Coming Soon Features */}
      <section className="py-12 sm:py-16 px-4 sm:px-6 lg:px-8 bg-gray-50">
        <div className="max-w-4xl mx-auto text-center">
          <h2 className="text-2xl sm:text-3xl font-poppins font-bold text-[#49c3c3] mb-6 sm:mb-8">Coming Soon</h2>
          <div className="grid gap-4 sm:gap-6 sm:grid-cols-2">
            <div className="bg-white rounded-lg p-4 sm:p-6 shadow-md">
              <div className="text-[#49c3c3] text-xl sm:text-2xl mb-3">📊</div>
              <h3 className="font-semibold text-base sm:text-lg mb-2">Multi-unit dashboard</h3>
            </div>
            <div className="bg-white rounded-lg p-4 sm:p-6 shadow-md">
              <div className="text-[#ff4fa1] text-xl sm:text-2xl mb-3">📄</div>
              <h3 className="font-semibold text-base sm:text-lg mb-2">CSV export + stocktaking</h3>
            </div>
            <div className="bg-white rounded-lg p-4 sm:p-6 shadow-md">
              <div className="text-[#8b5cf6] text-xl sm:text-2xl mb-3">📋</div>
              <h3 className="font-semibold text-base sm:text-lg mb-2">Stocktaking dashboard</h3>
            </div>
            <div className="bg-white rounded-lg p-4 sm:p-6 shadow-md">
              <div className="text-[#06b6d4] text-xl sm:text-2xl mb-3">👥</div>
              <h3 className="font-semibold text-base sm:text-lg mb-2">Bulk staff access</h3>
            </div>
          </div>
        </div>
      </section>

      {/* FAQ Section */}
      <section id="faq" className="py-12 sm:py-16 px-4 sm:px-6 lg:px-8 bg-white">
        <div className="max-w-4xl mx-auto">
          <div className="text-center mb-8 sm:mb-12">
            <h2 className="text-2xl sm:text-3xl md:text-4xl font-poppins font-bold text-[#49c3c3] mb-4">Frequently Asked Questions</h2>
          </div>
          <FAQAccordion />
        </div>
      </section>

      {/* Footer */}
      <footer className="bg-gray-800 text-white py-8 sm:py-12">
        <div className="max-w-6xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-6 sm:mb-8">
            <p className="text-base sm:text-lg italic mb-4 sm:mb-6">"Built by an Airbnb host for Airbnb operators. We know the chaos, and we've solved it."</p>
            
            <div className="mb-4 sm:mb-6">
              <h3 className="text-lg sm:text-xl font-semibold mb-3 sm:mb-4">Contact Us</h3>
              <p className="mb-2 text-sm sm:text-base">Email: <a href="mailto:info@sheetsherlock.com" className="text-[#49c3c3] hover:underline">info@sheetsherlock.com</a></p>
              <p className="text-sm sm:text-base">WhatsApp: <a href="https://wa.me/27615017035" className="text-[#49c3c3] hover:underline">+27 61 501 7035</a></p>
            </div>
          </div>
          
          <div className="border-t border-gray-700 pt-4 sm:pt-6 text-center text-xs sm:text-sm text-gray-400">
            <div className="flex flex-wrap justify-center gap-4 sm:gap-6">
              <Link href="/terms-and-conditions" className="hover:text-[#49c3c3] transition-colors duration-200">Terms & Conditions</Link>
              <Link href="/privacy-policy" className="hover:text-[#49c3c3] transition-colors duration-200">Privacy Policy</Link>
              <Link href="/cookie-policy" className="hover:text-[#49c3c3] transition-colors duration-200">Cookie Policy</Link>
            </div>
            <p className="mt-3 sm:mt-4">© 2024 Sheet Sherlock (Pty) Ltd. All rights reserved.</p>
          </div>
        </div>
      </footer>

      {/* Modals and Components */}
      <OrderFormModal 
        isOpen={isOrderModalOpen} 
        onClose={() => setIsOrderModalOpen(false)} 
      />
      <StickyCTA onOpenOrder={() => setIsOrderModalOpen(true)} />
    </div>
  );
}
